@@ -15,7 +15,7 @@ from dateutil.relativedelta import relativedelta  # 安装 pip install python-da
 from retrying import retry
 
 
-def datetime_toString(dt: datetime) -> str:
+def datetime_toStr(dt: datetime) -> str:
     """
     把datetime转成字符串
     :param dt: datetime.datetime.now
@@ -24,7 +24,7 @@ def datetime_toString(dt: datetime) -> str:
     return dt.strftime("%Y-%m-%d")
 
 
-def datetime_toString_detail(dt: datetime) -> str:
+def datetime_toStr_dil(dt: datetime) -> str:
     """
     把datetime转成字符串 详细版
     :param dt: datetime.datetime.now
@@ -32,6 +32,25 @@ def datetime_toString_detail(dt: datetime) -> str:
     """
     return dt.strftime("%Y-%m-%d %H:%M:%S")
 
+
+def datetime_toChinStr(dt: datetime) -> str:
+    """
+    把datetime转成中文字符串
+    :param dt: datetime.datetime.now
+    :return: '2020-01-01'
+    """
+    return dt.strftime("%Y年%m月%d日")
+
+
+def datetime_toChinStr_dil(dt: datetime) -> str:
+    """
+    把datetime转成字符串 详细版
+    :param dt: datetime.datetime.now
+    :return: '2020-01-01'
+    """
+    return dt.strftime("%Y年%m月%d日 %H时%M分%S秒")
+
+
 def get_now_date():
     """
     获取今日日期字符串
@@ -46,33 +65,33 @@ def get_now_time():
     """
     return datetime.datetime.now().strftime("%Y-%m-%d  %H:%M:%S")
 
-def string_toDatetime(string: str) -> datetime:
+def str_toDatetime(str: str) -> datetime:
     """
     把字符串转成datetime  精确到日
-    :param string: '2020-01-01'
+    :param str: '2020-01-01'
     :return:
     """
-    return datetime.datetime.strptime(string, "%Y-%m-%d")
+    return datetime.datetime.strptime(str, "%Y-%m-%d")
 
-def detail_string_toDatetime(string: str) -> datetime:
+def dil_str_toDatetime(str: str) -> datetime:
     """
     把字符串转成datetime 精确到秒
-    :param string: '2020-01-01'
+    :param str: '2020-01-01'
     :return:
     """
-    return datetime.datetime.strptime(string, "%Y-%m-%d  %H:%M:%S")
+    return datetime.datetime.strptime(str, "%Y-%m-%d  %H:%M:%S")
 
 
-def string_toTimestamp(strTime: str) -> int:
+def str_toTimestamp(strTime: str) -> int:
     """
     把字符串转成时间戳形式
     :param strTime:'2020-01-01'
     :return:<class 'int'> 1577808000
     """
-    return int(time.mktime(string_toDatetime(strTime).timetuple()))
+    return int(time.mktime(str_toDatetime(strTime).timetuple()))
 
 
-def timestamp_toString(stamp: int) -> str:
+def timestamp_tostr(stamp: int) -> str:
     """
     把时间戳转成字符串形式
     :param stamp: 1577808000
@@ -90,31 +109,38 @@ def ts_toStr_det(stamp: int) -> str:
     return time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(stamp))
 
 
-def datetime_toTimestamp(dateTime):
+def datetime_toTimestamp(dateTime: datetime):
     """
-    把datetime类型转外时间戳形式
+    把datetime类型转时间戳形式
     :param dateTime:datetime.datetime.now()
     :return:<class 'int'> 1608731584
     """
     return int(time.mktime(dateTime.timetuple()))
 
 
-def string_totime_detail(str_p):
+def str_totime_dil(str_p: str):
     """时间字符串转换成时间类型"""
     """2019-01-30 15:29:08"""
     dateTime_p = datetime.datetime.strptime(str_p, '%Y-%m-%d %H:%M:%S')
     return dateTime_p
 
 
-def substract_Time_detail(dateStr1: str, dateStr2: str) -> datetime:
+def str_totime(str_p: str):
+    """时间字符串转换成时间类型"""
+    """2019-01-30"""
+    dateTime_p = datetime.datetime.strptime(str_p, '%Y-%m-%d')
+    return dateTime_p
+
+
+def substract_Time_dil(dateStr1: str, dateStr2: str) -> datetime:
     """
         返回两个日期之间的差
         :param dateStr1:'2019-01-30 15:29:08'
         :param dateStr2:'2019-01-30 15:29:08'
         :return:<class 'datetime.timedelta'> 60 days, 0:00:00
     """
-    str1 = string_totime_detail(dateStr1)
-    str2 = string_totime_detail(dateStr2)
+    str1 = str_totime_dil(dateStr1)
+    str2 = str_totime_dil(dateStr2)
     difference = (str2 - str1)
     return {'day': difference.days, 'min': difference.seconds / 60, 'seconds': difference.seconds}
 
@@ -126,8 +152,8 @@ def substract_DateTime(dateStr1: str, dateStr2: str) -> datetime:
     :param dateStr2:'2020-01-01'
     :return:<class 'datetime.timedelta'> 60 days, 0:00:00
     """
-    d1 = string_toDatetime(dateStr1)
-    d2 = string_toDatetime(dateStr2)
+    d1 = str_toDatetime(dateStr1)
+    d2 = str_toDatetime(dateStr2)
     return d2 - d1
 
 
@@ -138,8 +164,8 @@ def substract_TimeStamp(dateStr1: str, dateStr2: str) -> int:
     :param dateStr2: '2020-02-01'
     :return: <class 'int'> -5184000
     """
-    ts1 = string_toTimestamp(dateStr1)
-    ts2 = string_toTimestamp(dateStr2)
+    ts1 = str_toTimestamp(dateStr1)
+    ts2 = str_toTimestamp(dateStr2)
     return ts1 - ts2
 
 
@@ -150,8 +176,8 @@ def compare_dateTime(dateStr1: str, dateStr2: str) -> bool:
     :param dateStr2:'2020-01-02'
     :return:<class 'bool'> False
     """
-    date1 = string_toDatetime(dateStr1)
-    date2 = string_toDatetime(dateStr2)
+    date1 = str_toDatetime(dateStr1)
+    date2 = str_toDatetime(dateStr2)
     return date1.date() > date2.date()
 
 
@@ -164,10 +190,10 @@ def dateTime_Add(dateStr: str, days=0, hours=0, minutes=0) -> datetime:
     :param minutes:1
     :return:<class 'datetime.datetime'> 2020-01-02 01:01:01
     """
-    date1 = detail_string_toDatetime(dateStr)
+    date1 = dil_str_toDatetime(dateStr)
     return date1 + datetime.timedelta(days=days, hours=hours, minutes=minutes)
 
-def dateTime_Subtraction(dateStr: str, days=0, hours=0, minutes=0) -> datetime:
+def date_time_subtraction(dateStr: str, days=0, hours=0, minutes=0) -> datetime:
     """
     指定日期减去 一个时间段，天，小时，或分钟之后的日期
     :param dateStr:'2020-01-01'
@@ -176,7 +202,7 @@ def dateTime_Subtraction(dateStr: str, days=0, hours=0, minutes=0) -> datetime:
     :param minutes:1
     :return:<class 'datetime.datetime'> 2020-01-02 01:01:01
     """
-    date1 = detail_string_toDatetime(dateStr)
+    date1 = dil_str_toDatetime(dateStr)
     return date1 - datetime.timedelta(days=days, hours=hours, minutes=minutes)
 
 
@@ -190,6 +216,25 @@ def format_nowtime_millisecond() -> int:
     return nowTime
 
 
+def get_week_day(date: datetime):
+    """
+    根据日期返回星期几
+    :param date:
+    :return:
+    """
+    week_day_dict = {
+        0: '星期一',
+        1: '星期二',
+        2: '星期三',
+        3: '星期四',
+        4: '星期五',
+        5: '星期六',
+        6: '星期日',
+    }
+    day = date.weekday()
+    return week_day_dict[day]
+
+
 def getBetweenDay(begin_date: str, end_date: str) -> list:
     """
     返回两个时间之间的日期列表
@@ -240,7 +285,7 @@ def month_datelist(start_day):
     return month_list
 
 
-def getdate(beforeOfDay):
+def getdate(beforeOfDay: int):
     """
     获取前1天或N天的日期，beforeOfDay=1：前1天；beforeOfDay=N：前N天
     :param beforeOfDay:
@@ -286,7 +331,6 @@ def monitoring_run_time(f):
         end_time = time.time()
         print("%s执行成功，用时:%.2f" % (f.__name__, end_time - start_time))
         return res
-
     return wrapper
 
 
@@ -299,21 +343,20 @@ def get_taobao_time():
         if ts.status_code == 200:
             json_data = json.loads(ts.text)
             return {"sysTime3": ts_toStr_det(json_data.get('time')),
-                    "sysTime2": timestamp_toString(json_data.get('time')),
+                    "sysTime2": timestamp_tostr(json_data.get('time')),
                     "sysTime1": f"{json_data.get('time')}"}
         else:
             json_data = {"sysTime3": ts_toStr_det(int(time.time())),
-                         "sysTime2": datetime_toString(datetime.datetime.now()),
+                         "sysTime2": datetime_toStr(datetime.datetime.now()),
                          "sysTime1": f"{datetime_toTimestamp(datetime.datetime.now())}"}
             return json_data
     except:
         json_data = {"sysTime3": ts_toStr_det(int(time.time())),
-                     "sysTime2": datetime_toString(datetime.datetime.now()),
+                     "sysTime2": datetime_toStr(datetime.datetime.now()),
                      "sysTime1": f"{datetime_toTimestamp(datetime.datetime.now())}"}
         return json_data
 
 
 if __name__ == '__main__':
     # month_begin_day = month_datelist('2020-01')
-    # print(getdate(1))
-    print(dateTime_Subtraction('2021-05-01 09:00:00', hours=3))
+    print(getdate(1))
